from difflib import get_close_matches
import re


def get_all_colors():
    colors = {
        'aero': '#7CB9E8',
        'aero blue': '#C0E8D5',
        'african violet': '#B284BE',
        'air force blue (raf)': '#5D8AA8',
        'air force blue (usaf)': '#00308F',
        'air superiority blue': '#72A0C1',
        'alabama crimson': '#AF002A',
        'alice blue': '#F0F8FF',
        'alizarin crimson': '#E32636',
        'alloy orange': '#C46210',
        'almond': '#EFDECD',
        'amaranth': '#E52B50',
        'amber': '#FFBF00',
        'amber (sae/ece)': '#FF7E00',
        'american rose': '#FF033E',
        'amethyst': '#9966CC',
        'android green': '#A4C639',
        'anti-flash white': '#F2F3F4',
        'antique brass': '#CD9575',
        'antique bronze': '#665D1E',
        'antique fuchsia': '#915C83',
        'antique ruby': '#841B2D',
        'antique white': '#FAEBD7',
        'ao (english)': '#008000',
        'apple green': '#8DB600',
        'apricot': '#FBCEB1',
        'aqua': '#00FFFF',
        'aquamarine': '#7FFFD4',
        'arctic lime': '#D0FF14',
        'army green': '#4B5320',
        'arsenic': '#3B444B',
        'artichoke': '#8F9779',
        'arylide yellow': '#E9D66B',
        'ash grey': '#B2BEB5',
        'asparagus': '#87A96B',
        'atomic tangerine': '#FF9966',
        'auburn': '#A52A2A',
        'aureolin': '#FDEE00',
        'avocado': '#568203',
        'azure': '#007FFF',
        'azure (web color)': '#F0FFFF',
        'azure mist/web': '#F0FFFF',
        'baby blue': '#89CFF0',
        'baby blue eyes': '#A1CAF1',
        'baby pink': '#F4C2C2',
        'baby powder': '#FEFEFA',
        'baker-miller pink': '#FF91AF',
        'ball blue': '#21ABCD',
        'banana mania': '#FAE7B5',
        'banana yellow': '#FFE135',
        'bangladesh green': '#006A4E',
        'barbie pink': '#E0218A',
        'barn red': '#7C0A02',
        'battleship grey': '#848482',
        'bazaar': '#98777B',
        'beau blue': '#BCD4E6',
        'beaver': '#9F8170',
        'beige': '#F5F5DC',
        'big dip o’ruby': '#9C2542',
        'bisque': '#FFE4C4',
        'bistre': '#3D2B1F',
        'bistre brown': '#967117',
        'bitter lemon': '#CAE00D',
        'bitter lime': '#BFFF00',
        'bittersweet': '#FE6F5E',
        'bittersweet shimmer': '#BF4F51',
        'black': '#000000',
        'black bean': '#3D0C02',
        'black leather jacket': '#253529',
        'black olive': '#3B3C36',
        'blanched almond': '#FFEBCD',
        'blast-off bronze': '#A57164',
        'bleu de france': '#318CE7',
        'blizzard blue': '#ACE5EE',
        'blond': '#FAF0BE',
        'blue': '#0000FF',
        'blue (crayola)': '#1F75FE',
        'blue (munsell)': '#0093AF',
        'blue (ncs)': '#0087BD',
        'blue (pantone)': '#0018A8',
        'blue (pigment)': '#333399',
        'blue (ryb)': '#0247FE',
        'blue bell': '#A2A2D0',
        'blue gray': '#6699CC',
        'blue-green': '#0D98BA',
        'blue-green (color wheel)': '#064E40',
        'blue jeans': '#5DADEC',
        'blue sapphire': '#126180',
        'blue violet': '#8A2BE2',
        'blue yonder': '#5072A7',
        'blueberry': '#4F86F7',
        'bluebonnet': '#1C1CF0',
        'blush': '#DE5D83',
        'bole': '#79443B',
        'bondi blue': '#0095B6',
        'bone': '#E3DAC9',
        'boston university red': '#CC0000',
        'bottle green': '#006A4E',
        'boysenberry': '#873260',
        'brandeis blue': '#0070FF',
        'brass': '#B5A642',
        'brick red': '#CB4154',
        'bright cerulean': '#1DACD6',
        'bright green': '#66FF00',
        'bright lavender': '#BF94E4',
        'bright lilac': '#D891EF',
        'bright maroon': '#C32148',
        'bright navy blue': '#1974D2',
        'bright pink': '#FF007F',
        'bright turquoise': '#08E8DE',
        'bright ube': '#D19FE8',
        'brilliant lavender': '#F4BBFF',
        'brilliant rose': '#FF55A3',
        'brink pink': '#FB607F',
        'british racing green': '#004225',
        'bronze': '#CD7F32',
        'bronze (metallic)': '#B08D57',
        'bronze yellow': '#737000',
        'brown (traditional)': '#964B00',
        'brown (web)': '#A52A2A',
        'brown-nose': '#6B4423',
        'brunswick green': '#1B4D3E',
        'bubble gum': '#FFC1CC',
        'bubbles': '#E7FEFF',
        'buff': '#F0DC82',
        'bud green': '#7BB661',
        'bulgarian rose': '#480607',
        'burgundy': '#800020',
        'burlywood': '#DEB887',
        'burnished brown': '#A17A74',
        'burnt orange': '#CC5500',
        'burnt sienna': '#E97451',
        'burnt umber': '#8A3324',
        'byzantine': '#BD33A4',
        'byzantium': '#702963',
        'cadet': '#536872',
        'cadet blue': '#5F9EA0',
        'cadet grey': '#91A3B0',
        'cadmium green': '#006B3C',
        'cadmium orange': '#ED872D',
        'cadmium red': '#E30022',
        'cadmium yellow': '#FFF600',
        'café au lait': '#A67B5B',
        'café noir': '#4B3621',
        'cal poly pomona green': '#1E4D2B',
        'cambridge blue': '#A3C1AD',
        'camel': '#C19A6B',
        'cameo pink': '#EFBBCC',
        'camouflage green': '#78866B',
        'canary': '#FFFF99',
        'canary yellow': '#FFEF00',
        'candy apple red': '#FF0800',
        'candy pink': '#E4717A',
        'capri': '#00BFFF',
        'caput mortuum': '#592720',
        'cardinal': '#C41E3A',
        'caribbean green': '#00CC99',
        'carmine': '#960018',
        'carmine (m&p)': '#D70040',
        'carnation pink': '#FFA6C9',
        'carnelian': '#B31B1B',
        'carolina blue': '#56A0D3',
        'carrot orange': '#ED9121',
        'castleton green': '#00563F',
        'catalina blue': '#062A78',
        'catawba': '#703642',
        'cedar chest': '#C95A49',
        'celadon': '#ACE1AF',
        'celadon blue': '#007BA7',
        'celadon green': '#2F847C',
        'celeste': '#B2FFFF',
        'celestial blue': '#4997D0',
        'cerise': '#DE3163',
        'cerise pink': '#EC3B83',
        'cerulean': '#007BA7',
        'cerulean blue': '#2A52BE',
        'cerulean frost': '#6D9BC3',
        'cg blue': '#007AA5',
        'cg red': '#E03C31',
        'chamoisee': '#A0785A',
        'champagne': '#F7E7CE',
        'charcoal': '#36454F',
        'charleston green': '#232B2B',
        'charm pink': '#E68FAC',
        'chartreuse (traditional)': '#DFFF00',
        'chartreuse (web)': '#7FFF00',
        'cherry': '#DE3163',
        'cherry blossom pink': '#FFB7C5',
        'chestnut': '#954535',
        'china pink': '#DE6FA1',
        'china rose': '#A8516E',
        'chinese red': '#AA381E',
        'chocolate (traditional)': '#7B3F00',
        'chocolate (web)': '#D2691E',
        'chrome yellow': '#FFA700',
        'cinereous': '#98817B',
        'cinnabar': '#E34234',
        'cinnamon': '#D2691E',
        'citrine': '#E4D00A',
        'classic rose': '#FBCCE7',
        'cobalt': '#0047AB',
        'cocoa brown': '#D2691E',
        'coconut': '#965A3E',
        'coffee': '#6F4E37',
        'columbia blue': '#B9D9EB',
        'congo pink': '#F88379',
        'cool black': '#002E63',
        'cool grey': '#8C92AC',
        'copper': '#B87333',
        'copper (crayola)': '#DA8A67',
        'copper penny': '#AD6F69',
        'copper red': '#CB6D51',
        'copper rose': '#996666',
        'coquelicot': '#FF3800',
        'coral': '#FF7F50',
        'coral pink': '#F88379',
        'coral red': '#FF4040',
        'cordovan': '#893F45',
        'corn': '#FBEC5D',
        'cornell red': '#B31B1B',
        'cornflower blue': '#6495ED',
        'cornsilk': '#FFF8DC',
        'cosmic cobalt': '#2E2D88',
        'cosmic latte': '#FFF8E7',
        'coyote brown': '#81613C',
        'cotton candy': '#FFBCD9',
        'cream': '#FFFDD0',
        'crimson': '#DC143C',
        'crimson glory': '#BE0032',
        'crimson red': '#990000',
        'cultured': '#F5F5F5',
        'cyan (process)': '#00B7EB',
        'cyber grape': '#58427C',
        'cyber yellow': '#FFD300',
        'cyclamen': '#F56FA1',
        'daffodil': '#FFFF31',
        'dandelion': '#F0E130',
        'dark blue-gray': '#666699',
        'dark bronze': '#804A00',
        'dark brown': '#654321',
        'dark byzantium': '#5D3954',
        'dark candy apple red': '#A40000',
        'dark cerulean': '#08457E',
        'dark chestnut': '#986960',
        'dark coral': '#CD5B45',
        'dark cyan': '#008B8B',
        'dark electric blue': '#536878',
        'dark goldenrod': '#B8860B',
        'dark gray (x11)': '#A9A9A9',
        'dark green': '#013220',
        'dark green (x11)': '#006400',
        'dark gunmetal': '#1F262A',
        'dark imperial blue': '#00416A',
        'dark jungle green': '#1A2421',
        'dark khaki': '#BDB76B',
        'dark lava': '#483C32',
        'dark liver': '#534B4F',
        'dark liver (horses)': '#543D37',
        'dark magenta': '#8B008B',
        'dark midnight blue': '#003366',
        'dark moss green': '#4A5D23',
        'dark olive green': '#556B2F',
        'dark orange': '#FF8C00',
        'dark orchid': '#9932CC',
        'dark pastel blue': '#779ECB',
        'dark pastel green': '#03C03C',
        'dark pastel purple': '#966FD6',
        'dark pastel red': '#C23B22',
        'dark pink': '#E75480',
        'dark powder blue': '#003399',
        'dark puce': '#4F3A3C',
        'dark purple': '#301934',
        'dark raspberry': '#872657',
        'dark red': '#8B0000',
        'dark salmon': '#E9967A',
        'dark scarlet': '#560319',
        'dark sea green': '#8FBC8F',
        'dark sienna': '#3C1414',
        'dark sky blue': '#8CBED6',
        'dark slate blue': '#483D8B',
        'dark slate gray': '#2F4F4F',
        'dark spring green': '#177245',
        'dark tan': '#918151',
        'dark tangerine': '#FFA812',
        'dark taupe': '#483C32',
        'dark terra cotta': '#CC4E5C',
        'dark turquoise': '#00CED1',
        'dark vanilla': '#D1BEA8',
        'dark violet': '#9400D3',
        'dark yellow': '#9B870C',
        'dartmouth green': '#00703C',
        'davy\'s grey': '#555555',
        'debian red': '#D70A53',
        'deep aquamarine': '#40826D',
        'deep carmine': '#A9203E',
        'deep carmine pink': '#EF3038',
        'deep carrot orange': '#E9692C',
        'deep cerise': '#DA3287',
        'deep champagne': '#FAD6A5',
        'deep chestnut': '#B94E48',
        'deep coffee': '#704241',
        'deep fuchsia': '#C154C1',
        'deep jungle green': '#004B49',
        'deep lilac': '#9955BB',
        'deep magenta': '#CC00CC',
        'deep mauve': '#D473D4',
        'deep moss green': '#355E3B',
        'deep peach': '#FFCBA4',
        'deep pink': '#FF1493',
        'deep puce': '#A95C68',
        'deep ruby': '#843F5B',
        'deep saffron': '#FF9933',
        'deep sky blue': '#00BFFF',
        'deep tuscan red': '#66424D',
        'denim': '#1560BD',
        'desert': '#C19A6B',
        'desert sand': '#EDC9AF',
        'dim gray': '#696969',
        'dodger blue': '#1E90FF',
        'dogwood rose': '#D71868',
        'dollar bill': '#85BB65',
        'donkey brown': '#664C28',
        'drab': '#967117',
        'duke blue': '#00009C',
        'earth yellow': '#E1A95F',
        'ebony': '#555D50',
        'ecru': '#C2B280',
        'eggplant': '#614051',
        'eggshell': '#F0EAD6',
        'egyptian blue': '#1034A6',
        'electric blue': '#7DF9FF',
        'electric crimson': '#FF003F',
        'electric cyan': '#00FFFF',
        'electric green': '#00FF00',
        'electric indigo': '#6F00FF',
        'electric lavender': '#F4BBFF',
        'electric lime': '#CCFF00',
        'electric purple': '#BF00FF',
        'electric ultramarine': '#3F00FF',
        'electric violet': '#8F00FF',
        'electric yellow': '#FFFF33',
        'emerald': '#50C878',
        'eminence': '#6C3082',
        'english green': '#1B4D3E',
        'english lavender': '#B48395',
        'english red': '#AB4B52',
        'english vermillion': '#CC474B',
        'english violet': '#563C5C',
        'erin': '#00FF40',
        'eton blue': '#96C8A2',
        'fallow': '#C19A6B',
        'falu red': '#801818',
        'fandango': '#B53389',
        'fandango pink': '#DE5285',
        'fashion fuchsia': '#F400A1',
        'fawn': '#E5AA70',
        'feldgrau': '#4D5D53',
        'fern green': '#4F7942',
        'ferrari red': '#FF2800',
        'field drab': '#6C541E',
        'fire engine red': '#CE2029',
        'firebrick': '#B22222',
        'flame': '#E25822',
        'flamingo pink': '#FC8EAC',
        'flattery': '#6B4423',
        'flavescent': '#F7E98E',
        'flax': '#EEDC82',
        'flirt': '#A2006D',
        'floral white': '#FFFAF0',
        'fluorescent blue': '#15F4EE',
        'forest green (traditional)': '#014421',
        'forest green (web)': '#228B22',
        'french beige': '#A67B5B',
        'french bistre': '#856D4D',
        'french blue': '#0072BB',
        'french fuchsia': '#FD3F92',
        'french lilac': '#86608E',
        'french lime': '#9EFD38',
        'french mauve': '#D473D4',
        'french pink': '#FD6C9E',
        'french raspberry': '#C72C48',
        'french rose': '#F64A8A',
        'french sky blue': '#77B5FE',
        'french violet': '#8806CE',
        'frostbite': '#E936A7',
        'fuchsia': '#FF00FF',
        'fuchsia (crayola)': '#C154C1',
        'fuchsia pink': '#FF77FF',
        'fuchsia purple': '#CC397B',
        'fuchsia rose': '#C74375',
        'fulvous': '#E48400',
        'fuzzy wuzzy': '#CC6666',
        'gainsboro': '#DCDCDC',
        'gamboge': '#E49B0F',
        'gamboge orange (brown)': '#996600',
        'generic viridian': '#007F66',
        'ghost white': '#F8F8FF',
        'giants orange': '#FE5A1D',
        'ginger': '#B06500',
        'glaucous': '#6082B6',
        'glitter': '#E6E8FA',
        'go green': '#00AB66',
        'gold (metallic)': '#D4AF37',
        'gold (web) (golden)': '#FFD700',
        'gold fusion': '#85754E',
        'golden brown': '#996515',
        'golden poppy': '#FCC200',
        'golden yellow': '#FFDF00',
        'goldenrod': '#DAA520',
        'granny smith apple': '#A8E4A0',
        'grape': '#6F2DA8',
        'gray (html/css gray)': '#808080',
        'gray (x11 gray)': '#BEBEBE',
        'gray-asparagus': '#465945',
        'gray-blue': '#8C92AC',
        'green (color wheel) (x11 green)': '#00FF00',
        'green (crayola)': '#1CAC78',
        'green (html/css color)': '#008000',
        'green (munsell)': '#00A877',
        'green (ncs)': '#009F6B',
        'green (pantone)': '#00AD43',
        'green (pigment)': '#00A550',
        'green (ryb)': '#66B032',
        'green-blue': '#1164B4',
        'green-blue (color wheel)': '#01796F',
        'green-cyan': '#009966',
        'green lizard': '#A7F432',
        'green sheen': '#6EAEA1',
        'green-yellow': '#ADFF2F',
        'grullo': '#A99A86',
        'guppie green': '#00FF7F',
        'halayà úbe': '#663854',
        'han blue': '#446CCF',
        'han purple': '#5218FA',
        'hansa yellow': '#E9D66B',
        'harlequin': '#3FFF00',
        'harlequin green': '#46CB18',
        'harvard crimson': '#C90016',
        'harvest gold': '#DA9100',
        'heart gold': '#808000',
        'heliotrope': '#DF73FF',
        'heliotrope gray': '#AA98A9',
        'heliotrope magenta': '#AA00BB',
        'hollywood cerise': '#F400A1',
        'honeydew': '#F0FFF0',
        'honolulu blue': '#006DB0',
        'hooker\'s green': '#49796B',
        'hot magenta': '#FF1DCE',
        'hot pink': '#FF69B4',
        'hunter green': '#355E3B',
        'iceberg': '#71A6D2',
        'icterine': '#FCF75E',
        'illuminating emerald': '#319177',
        'imperial': '#602F6B',
        'imperial blue': '#002395',
        'imperial purple': '#66023C',
        'imperial red': '#ED2939',
        'inchworm': '#B2EC5D',
        'independence': '#4C516D',
        'india green': '#138808',
        'indian red': '#CD5C5C',
        'indian yellow': '#E3A857',
        'indigo (dye)': '#00416A',
        'indigo (web)': '#4B0082',
        'international klein blue': '#002FA7',
        'international orange (aerospace)': '#FF4F00',
        'international orange (engineering)': '#BA160C',
        'international orange (golden gate bridge)': '#C0362C',
        'iris': '#5A4FCF',
        'irresistible': '#B3446C',
        'isabelline': '#F4F0EC',
        'islamic green': '#009000',
        'italian sky blue': '#B2FFFF',
        'ivory': '#FFFFF0',
        'jade': '#00A86B',
        'japanese carmine': '#9D2933',
        'japanese indigo': '#264348',
        'japanese violet': '#5B3256',
        'jasmine': '#F8DE7E',
        'jasper': '#D73B3E',
        'jazzberry jam': '#A50B5E',
        'jelly bean': '#DA614E',
        'jet': '#343434',
        'jonquil': '#FADA5E',
        'jordy blue': '#8AB9F1',
        'june bud': '#BDDA57',
        'jungle green': '#29AB87',
        'kelly green': '#4CBB17',
        'kenyan copper': '#7C1C05',
        'keppel': '#3AB09E',
        'key lime': '#E8F48C',
        'khaki (web) (khaki)': '#C3B091',
        'khaki (x11) (light khaki)': '#F0E68C',
        'ku crimson': '#E8000D',
        'la salle green': '#087830',
        'languid lavender': '#D6CADD',
        'lapis lazuli': '#26619C',
        'laser lemon': '#FFFF66',
        'laurel green': '#A9BA9D',
        'lava': '#CF1020',
        'lavender (floral)': '#B57EDC',
        'lavender (web)': '#E6E6FA',
        'lavender blue': '#CCCCFF',
        'lavender blush': '#FFF0F5',
        'lavender gray': '#C4C3D0',
        'lavender indigo': '#9457EB',
        'lavender magenta': '#EE82EE',
        'lavender mist': '#E6E6FA',
        'lavender pink': '#FBAED2',
        'lavender purple': '#967BB6',
        'lavender rose': '#FBA0E3',
        'lawn green': '#7CFC00',
        'lemon': '#FFF700',
        'lemon chiffon': '#FFFACD',
        'lemon curry': '#CCA01D',
        'lemon glacier': '#FDFF00',
        'lemon meringue': '#F6EABE',
        'lemon yellow': '#FFF44F',
        'lenurple': '#BA93D8',
        'licorice': '#1A1110',
        'liberty': '#545AA7',
        'light apricot': '#FDD5B1',
        'light blue': '#ADD8E6',
        'light brown': '#B5651D',
        'light carmine pink': '#E66771',
        'light coral': '#F08080',
        'light cornflower blue': '#93CCEA',
        'light crimson': '#F56991',
        'light cyan': '#E0FFFF',
        'light fuchsia pink': '#F984EF',
        'light goldenrod yellow': '#FAFAD2',
        'light gray': '#D3D3D3',
        'light green': '#90EE90',
        'light khaki': '#F0E68C',
        'light pastel purple': '#B19CD9',
        'light pink': '#FFB6C1',
        'light red ochre': '#E97451',
        'light salmon': '#FFA07A',
        'light salmon pink': '#FF9999',
        'light sea green': '#20B2AA',
        'light sky blue': '#87CEFA',
        'light slate gray': '#778899',
        'light steel blue': '#B0C4DE',
        'light taupe': '#B38B6D',
        'light thulian pink': '#E68FAC',
        'light yellow': '#FFFFE0',
        'lilac': '#C8A2C8',
        'lilac luster': '#AE98AA',
        'lime (color wheel)': '#BFFF00',
        'lime (web) (x11 green)': '#00FF00',
        'lime green': '#32CD32',
        'limerick': '#9DC209',
        'lincoln green': '#195905',
        'linen': '#FAF0E6',
        'lion': '#C19A6B',
        'little boy blue': '#6CA0DC',
        'liver': '#674C47',
        'liver (dogs)': '#B86D29',
        'liver (organ)': '#6C2E1F',
        'liver chestnut': '#987456',
        'lumber': '#FFE4CD',
        'lust': '#E62020',
        'magenta': '#FF00FF',
        'magenta (crayola)': '#FF55A3',
        'magenta (dye)': '#CA1F7B',
        'magenta (pantone)': '#D0417E',
        'magenta (process)': '#FF0090',
        'magenta haze': '#9F4576',
        'magic mint': '#AAF0D1',
        'magnolia': '#F8F4FF',
        'mahogany': '#C04000',
        'maize': '#FBEC5D',
        'majorelle blue': '#6050DC',
        'malachite': '#0BDA51',
        'manatee': '#979AAA',
        'mango tango': '#FF8243',
        'mantis': '#74C365',
        'mardi gras': '#880085',
        'marigold': '#EAA221',
        'maroon (crayola)': '#C32148',
        'maroon (html/css)': '#800000',
        'maroon (x11)': '#B03060',
        'mauve': '#E0B0FF',
        'mauve taupe': '#915F6D',
        'mauvelous': '#EF98AA',
        'maya blue': '#73C2FB',
        'meat brown': '#E5B73B',
        'medium aquamarine': '#66DDAA',
        'medium blue': '#0000CD',
        'medium candy apple red': '#E2062C',
        'medium carmine': '#AF4035',
        'medium champagne': '#F3E5AB',
        'medium electric blue': '#035096',
        'medium jungle green': '#1C352D',
        'medium lavender magenta': '#DDA0DD',
        'medium orchid': '#BA55D3',
        'medium persian blue': '#0067A5',
        'medium purple': '#9370DB',
        'medium red-violet': '#BB3385',
        'medium ruby': '#AA4069',
        'medium sea green': '#3CB371',
        'medium sky blue': '#80DAEB',
        'medium slate blue': '#7B68EE',
        'medium spring bud': '#C9DC87',
        'medium spring green': '#00FA9A',
        'medium taupe': '#674C47',
        'medium teal blue': '#0054B4',
        'medium turquoise': '#48D1CC',
        'medium tuscan red': '#79443B',
        'medium vermilion': '#D9603B',
        'medium violet-red': '#C71585',
        'mellow apricot': '#F8B878',
        'mellow yellow': '#F8DE7E',
        'melon': '#FDBCB4',
        'midnight blue': '#191970',
        'midnight green (eagle green)': '#004953',
        'mikado yellow': '#FFC40C',
        'mindaro': '#E3F988',
        'ming': '#36747D',
        'mint': '#3EB489',
        'mint cream': '#F5FFFA',
        'mint green': '#98FF98',
        'misty rose': '#FFE4E1',
        'moccasin': '#FAEBD7',
        'mode beige': '#967117',
        'moonstone blue': '#73A9C2',
        'mordant red 19': '#AE0C00',
        'moss green': '#8A9A5B',
        'mountain meadow': '#30BA8F',
        'mountbatten pink': '#997A8D',
        'msu green': '#18453B',
        'mulberry': '#C54B8C',
        'mustard': '#FFDB58',
        'myrtle green': '#317873',
        'nadeshiko pink': '#F6ADC6',
        'napier green': '#2A8000',
        'naples yellow': '#FADA5E',
        'navajo white': '#FFDEAD',
        'navy blue': '#000080',
        'neon blue': '#1B03A3',
        'neon carrot': '#FFA343',
        'neon green': '#39FF14',
        'neon fuchsia': '#FE4164',
        'neon pink': '#FE347E',
        'new york pink': '#D7837F',
        'nickel': '#727472',
        'non-photo blue': '#A4DDED',
        'nyanza': '#E9FFDB',
        'ocean blue': '#4F42B5',
        'ocean green': '#48BF91',
        'ochre': '#CC7722',
        'office green': '#008000',
        'old gold': '#CFB53B',
        'old lace': '#FDF5E6',
        'old lavender': '#796878',
        'old mauve': '#673147',
        'old rose': '#C08081',
        'old silver': '#848482',
        'olive': '#808000',
        'olive drab (#3)': '#6B8E23',
        'olive drab #7': '#3C341F',
        'olivine': '#9AB973',
        'onyx': '#353839',
        'opera mauve': '#B784A7',
        'orange (color wheel)': '#FF7F00',
        'orange (crayola)': '#FF7538',
        'orange (pantone)': '#FF5800',
        'orange (ryb)': '#FB9902',
        'orange (web)': '#FFA500',
        'orange peel': '#FF9F00',
        'orange-red': '#FF4500',
        'orange soda': '#FA5B3D',
        'orange-yellow': '#F5BD1F',
        'orchid': '#DA70D6',
        'orchid pink': '#F2BDCD',
        'orioles orange': '#FB4F14',
        'otter brown': '#654321',
        'outer space': '#414A4C',
        'outrageous orange': '#FF6E4A',
        'oxblood': '#800020',
        'oxford blue': '#002147',
        'pakistan green': '#006600',
        'palatinate blue': '#273BE2',
        'palatinate purple': '#682860',
        'pale aqua': '#BCD4E6',
        'pale cerulean': '#9BC4E2',
        'pale pink': '#FADADD',
        'pale purple (pantone)': '#FAE6FA',
        'pale silver': '#C9C0BB',
        'pale spring bud': '#ECEBBD',
        'pansy purple': '#78184A',
        'paolo veronese green': '#009B7D',
        'papaya whip': '#FFEFD5',
        'paradise pink': '#E63E62',
        'parchment': '#F1E9D2',
        'paris green': '#50C878',
        'pastel blue': '#ADD9D1',
        'pastel brown': '#836953',
        'pastel gray': '#CFCFC4',
        'pastel green': '#77DD77',
        'pastel magenta': '#F49AC2',
        'pastel orange': '#FFB347',
        'pastel pink': '#DEA5A4',
        'pastel purple': '#B39EB5',
        'pastel red': '#FF6961',
        'pastel violet': '#CB99C9',
        'pastel yellow': '#FDFD96',
        'patriarch': '#800080',
        'payne\'s grey': '#536878',
        'peach': '#FFE5B4',
        'peach (crayola)': '#FFCBA4',
        'peach-orange': '#FFCC99',
        'peach puff': '#FFDAB9',
        'peach-yellow': '#FADFAD',
        'pear': '#D1E231',
        'pearl': '#EAE0C8',
        'pearl aqua': '#88D8C0',
        'pearly purple': '#B768A2',
        'peridot': '#E6E200',
        'periwinkle': '#CCCCFF',
        'persian blue': '#1C39BB',
        'persian green': '#00A693',
        'persian indigo': '#32127A',
        'persian orange': '#D99058',
        'persian pink': '#F77FBE',
        'persian plum': '#701C1C',
        'persian red': '#CC3333',
        'persian rose': '#FE28A2',
        'persimmon': '#EC5800',
        'peru': '#CD853F',
        'phlox': '#DF00FF',
        'phthalo blue': '#000F89',
        'phthalo green': '#123524',
        'picton blue': '#45B1E8',
        'pictorial carmine': '#C30B4E',
        'piggy pink': '#FDDDE6',
        'pine green': '#01796F',
        'pineapple': '#563C5C',
        'pink': '#FFC0CB',
        'pink lace': '#FFDDF4',
        'pink lavender': '#D8B2D1',
        'pink pearl': '#E7ACCF',
        'pink sherbet': '#F78FA7',
        'pistachio': '#93C572',
        'platinum': '#E5E4E2',
        'plum (traditional)': '#8E4585',
        'plum (web)': '#DDA0DD',
        'pomp and power': '#86608E',
        'popstar': '#BE4F62',
        'portland orange': '#FF5A36',
        'powder blue (web)': '#B0E0E6',
        'princeton orange': '#FF8F00',
        'prune': '#701C1C',
        'prussian blue': '#003153',
        'psychedelic purple': '#DF00FF',
        'puce': '#CC8899',
        'pullman brown (ups brown)': '#644117',
        'pullman green': '#3B331C',
        'pumpkin': '#FF7518',
        'purple (html/css)': '#800080',
        'purple (munsell)': '#9F00C5',
        'purple (x11)': '#A020F0',
        'purple heart': '#69359C',
        'purple mountain majesty': '#9678B6',
        'purple navy': '#4E5180',
        'purple pizzazz': '#FE4EDA',
        'purple taupe': '#50404D',
        'quartz': '#51484F',
        'queen blue': '#436B95',
        'queen pink': '#E8CCD7',
        'quick silver': '#A6A6A6',
        'quinacridone magenta': '#8E3A59',
        'rackley': '#5D8AA8',
        'radical red': '#FF355E',
        'raisin black': '#242124',
        'rajah': '#FBAB60',
        'raspberry': '#E30B5C',
        'raspberry glace': '#915F6D',
        'raspberry pink': '#E25098',
        'raspberry rose': '#B3446C',
        'raw sienna': '#D68A59',
        'raw umber': '#826644',
        'razzle dazzle rose': '#FF33CC',
        'razzmatazz': '#E3256B',
        'razzmic berry': '#8D4E85',
        'rebecca purple': '#663399',
        'red': '#FF0000',
        'red (crayola)': '#EE204D',
        'red (munsell)': '#F2003C',
        'red (ncs)': '#C40233',
        'red (pigment)': '#ED1C24',
        'red (ryb)': '#FE2712',
        'red-orange': '#FF5349',
        'red-orange (color wheel)': '#FF4500',
        'red-orange (crayola)': '#FF681F',
        'red-purple': '#E40078',
        'red salsa': '#FD3A4A',
        'red-violet': '#C71585',
        'red-violet (crayola)': '#C0448F',
        'red-violet (color wheel)': '#922B3E',
        'redwood': '#A45A52',
        'resolution blue': '#002387',
        'rhythm': '#777696',
        'rich black': '#004040',
        'rich black (fogra29)': '#010B13',
        'rich black (fogra39)': '#010203',
        'rich brilliant lavender': '#F1A7FE',
        'rich carmine': '#D70040',
        'rich electric blue': '#0892D0',
        'rich lavender': '#A76BCF',
        'rich lilac': '#B666D2',
        'rich maroon': '#B03060',
        'rifle green': '#414833',
        'robin egg blue': '#00CCCC',
        'rocket metallic': '#8A7F80',
        'romantic rose': '#FF007F',
        'root beer': '#200000',
        'rose': '#FF007F',
        'rose bonbon': '#F9429E',
        'rose ebony': '#674846',
        'rose gold': '#B76E79',
        'rose madder': '#E32636',
        'rose pink': '#FF66CC',
        'rose quartz': '#AA98A9',
        'rose red': '#C21E56',
        'rose taupe': '#905D5D',
        'rose vale': '#AB4E52',
        'rosewood': '#65000B',
        'rosso corsa': '#D40000',
        'rosy brown': '#BC8F8F',
        'royal azure': '#0038A8',
        'royal blue (dark)': '#002366',
        'royal blue (light)': '#4169E1',
        'royal purple': '#7851A9',
        'royal yellow': '#FADA5E',
        'rubine red': '#D10056',
        'ruby': '#E0115F',
        'ruby red': '#9B111E',
        'ruddy': '#FF0028',
        'ruddy brown': '#BB6528',
        'ruddy pink': '#E18E96',
        'rufous': '#A81C07',
        'russet': '#80461B',
        'russian green': '#679267',
        'russian violet': '#32174D',
        'rust': '#B7410E',
        'rusty red': '#DA2C43',
        'sacramento state green': '#00563F',
        'saddle brown': '#8B4513',
        'safety orange (blaze orange)': '#FF6700',
        'safety yellow': '#EED202',
        'saffron': '#F4C430',
        'sage': '#BCB88A',
        'st. patrick\'s blue': '#23297A',
        'salmon': '#FA8072',
        'salmon pink': '#FF91A4',
        'sand': '#C2B280',
        'sand dune': '#967117',
        'sandstorm': '#ECD540',
        'sandy brown': '#F4A460',
        'sandy taupe': '#967117',
        'sangria': '#92000A',
        'sap green': '#507D2A',
        'sapphire': '#0F52BA',
        'sapphire blue': '#0067A5',
        'sasquatch socks': '#FF4681',
        'satin sheen gold': '#CBA135',
        'scarlet': '#FF2400',
        'schauss pink': '#FF91AF',
        'school bus yellow': '#FFD800',
        'screamin\' green': '#66FF66',
        'sea blue': '#006994',
        'sea green': '#2E8B57',
        'seal brown': '#59260B',
        'seashell': '#FFF5EE',
        'selective yellow': '#FFBA00',
        'sepia': '#704214',
        'shadow': '#8A795D',
        'shamrock green': '#009E60',
        'shocking pink': '#FC0FC0',
        'shocking pink (crayola)': '#FF6FFF',
        'sienna': '#882D17',
        'silver': '#C0C0C0',
        'sinopia': '#CB410B',
        'skobeloff': '#007474',
        'sky blue': '#87CEEB',
        'sky magenta': '#CF71AF',
        'slate blue': '#6A5ACD',
        'slate gray': '#708090',
        'slimy green': '#299617',
        'smitten': '#C84186',
        'smoke': '#738276',
        'smoky black': '#100C08',
        'smoky topaz': '#933D41',
        'snow': '#FFFAFA',
        'soap': '#CEC8EF',
        'sonic silver': '#757575',
        'space cadet': '#1D2951',
        'spanish bistre': '#807532',
        'spanish blue': '#0070B8',
        'spanish carmine': '#D10047',
        'spanish crimson': '#E51A4C',
        'spanish gray': '#989898',
        'spanish green': '#009150',
        'spanish orange': '#E86100',
        'spanish pink': '#F7BFBE',
        'spanish red': '#E60026',
        'spanish sky blue': '#00FFFF',
        'spanish violet': '#4C2882',
        'spanish viridian': '#007F5C',
        'spring bud': '#A7FC00',
        'spring green': '#00FF7F',
        'star command blue': '#007BB8',
        'steel blue': '#4682B4',
        'steel pink': '#CC33CC',
        'stil de grain yellow': '#FADA5E',
        'stizza': '#990000',
        'stormcloud': '#4F666A',
        'straw': '#E4D96F',
        'strawberry': '#FC5A8D',
        'sunglow': '#FFCC33',
        'sunray': '#E3AB57',
        'sunset': '#FAD6A5',
        'super pink': '#CF6BA9',
        'sweet brown': '#A83731',
        'syracuse orange': '#D44500',
        'tan': '#D2B48C',
        'tangelo': '#F94D00',
        'tangerine': '#F28500',
        'tangerine yellow': '#FFCC00',
        'tango pink': '#E4717A',
        'taupe': '#483C32',
        'taupe gray': '#8B8589',
        'tea green': '#D0F0C0',
        'tea rose (orange)': '#F88379',
        'tea rose (rose)': '#F4C2C2',
        'teal': '#008080',
        'teal blue': '#367588',
        'teal deer': '#99E6B3',
        'teal green': '#00827F',
        'telemagenta': '#CF3476',
        'temptress': '#3C2126',
        'tenn\u00e9 (tawny)': '#CD5700',
        'terra cotta': '#E2725B',
        'thistle': '#D8BFD8',
        'thulian pink': '#DE6FA1',
        'tickle me pink': '#FC89AC',
        'tiffany blue': '#0ABAB5',
        'tiger\'s eye': '#E08D3C',
        'timberwolf': '#DBD7D2',
        'titanium yellow': '#EEE600',
        'tomato': '#FF6347',
        'toolbox': '#746CC0',
        'topaz': '#FFC87C',
        'tractor red': '#FD0E35',
        'trolley grey': '#808080',
        'tropical rain forest': '#00755E',
        'true blue': '#0073CF',
        'tufts blue': '#417DC1',
        'tumbleweed': '#DEAA88',
        'turkish rose': '#B57281',
        'turquoise': '#40E0D0',
        'turquoise blue': '#00FFEF',
        'turquoise green': '#A0D6B4',
        'tuscan red': '#7C4848',
        'twilight lavender': '#8A496B',
        'tyrian purple': '#66023C',
        'ua blue': '#0033AA',
        'ua red': '#D9004C',
        'ube': '#8878C3',
        'ucla blue': '#536895',
        'ucla gold': '#FFB300',
        'ufo green': '#3CD070',
        'ultramarine': '#120A8F',
        'ultramarine blue': '#4166F5',
        'ultra pink': '#FF6FFF',
        'ultra red': '#FC6C85',
        'umber': '#635147',
        'unbleached silk': '#FFDDCA',
        'united nations blue': '#5B92E5',
        'university of california gold': '#B78727',
        'unmellow yellow': '#FFFF66',
        'up forest green': '#014421',
        'up maroon': '#7B1113',
        'upsdell red': '#AE2029',
        'urobilin': '#E1AD21',
        'usafa blue': '#004F98',
        'usc cardinal': '#990000',
        'usc gold': '#FFCC00',
        'utah crimson': '#D3003F',
        'vanilla': '#F3E5AB',
        'vanilla ice': '#F38FA9',
        'vegas gold': '#C5B358',
        'venetian red': '#C80815',
        'verdigris': '#43B3AE',
        'vermilion (cinnabar)': '#E34234',
        'vermilion (plochere)': '#D9603B',
        'veronica': '#A020F0',
        'violet': '#8A2BE2',
        'violet (color wheel)': '#7F00FF',
        'violet (ryb)': '#8601AF',
        'violet (web)': '#EE82EE',
        'violet-blue': '#324AB2',
        'violet-red': '#F75394',
        'viridian': '#40826D',
        'viridian green': '#009698',
        'vista blue': '#7C9ED9',
        'vivid auburn': '#922724',
        'vivid burgundy': '#9F1D35',
        'vivid cerise': '#DA1D81',
        'vivid tangerine': '#FFA089',
        'vivid violet': '#9F00FF',
        'volt': '#CEFF00',
        'warm black': '#004242',
        'wheat': '#F5DEB3',
        'white': '#FFFFFF',
        'wild blue yonder': '#A2ADD0',
        'wild orchid': '#D470A2',
        'wild strawberry': '#FF43A4',
        'wild watermelon': '#FC6C85',
        'wine': '#722F37',
        'wine dregs': '#673147',
        'wisteria': '#C9A0DC',
        'wood brown': '#C19A6B',
        'xanadu': '#738678',
        'yale blue': '#0F4D92',
        'yellow': '#FFFF00',
        'yellow (crayola)': '#FCE883',
        'yellow (munsell)': '#EFCC00',
        'yellow (ncs)': '#FFD300',
        'yellow (pantone)': '#FEDF00',
        'yellow (process)': '#FFEF00',
        'yellow (ryb)': '#FEFE33',
        'yellow-green': '#9ACD32',
        'yellow-green (crayola)': '#C5E384',
        'yellow-green (color wheel)': '#30B21A',
        'yellow orange': '#FFAE42',
        'yellow-orange': '#FF9505',
        'yellow sunshine': '#FFF700',
        'yinmn blue': '#2E5090',
        'zaffre': '#0014A8',
        'zomp': '#39A78E',
        "black": "#000000",
    "white": "#FFFFFF",
    "red": "#FF0000",
    "lime": "#00FF00",
    "blue": "#0000FF",
    "yellow": "#FFFF00",
    "cyan": "#00FFFF",
    "magenta": "#FF00FF",
    "silver": "#C0C0C0",
    "gray": "#808080",
    "maroon": "#800000",
    "olive": "#808000",
    "green": "#008000",
    "purple": "#800080",
    "teal": "#008080",
    "navy": "#000080",
    "dark red": "#8B0000",
    "dark green": "#006400",
    "dark blue": "#00008B",
    "dark cyan": "#008B8B",
    "dark magenta": "#8B008B",
    "dark slate gray": "#2F4F4F",
    "dark olive green": "#556B2F",
    "dark slate blue": "#483D8B",
    "dark orchid": "#9932CC",
    "dark salmon": "#E9967A",
    "dark sea green": "#8FBC8F",
    "dark turquoise": "#00CED1",
    "dark khaki": "#BDB76B",
    "dark goldenrod": "#B8860B",
    "dark violet": "#9400D3",
    "dark orange": "#FF8C00",
    "dark gray": "#A9A9A9",
    "dark brown": "#654321",
    "dark sienna": "#8B4513",
    "dark chocolate": "#D2691E",
    "light gray": "#D3D3D3",
    "light cyan": "#E0FFFF",
    "light pink": "#FFB6C1",
    "light green": "#90EE90",
    "light yellow": "#FFFFE0",
    "light blue": "#ADD8E6",
    "light coral": "#F08080",
    "light steel blue": "#B0C4DE",
    "light sky blue": "#87CEFA",
    "light sea green": "#20B2AA",
    "light salmon": "#FFA07A",
    "light slate gray": "#778899",
    "light goldenrod yellow": "#FAFAD2",
    "light orchid": "#E6A8D7",
    "light turquoise": "#AFEEEE",
    "light green yellow": "#ADFF2F",
    "light blue violet": "#8A2BE2",
    "light purple": "#D8BFD8",
    "dark slate gray": "#2F4F4F",
    "dark olive green": "#556B2F",
    "dark slate blue": "#483D8B",
    "dark orchid": "#9932CC",
    "dark salmon": "#E9967A",
    "dark sea green": "#8FBC8F",
    "dark turquoise": "#00CED1",
    "dark khaki": "#BDB76B",
    "dark goldenrod": "#B8860B",
    "dark violet": "#9400D3",
    "dark orange": "#FF8C00",
    "dark gray": "#A9A9A9",
    "dark brown": "#654321",
    "dark sienna": "#8B4513",
    "dark chocolate": "#D2691E",
    "light gray": "#D3D3D3",
    "light cyan": "#E0FFFF",
    "light pink": "#FFB6C1",
    "light green": "#90EE90",
    "light yellow": "#FFFFE0",
    "light blue": "#ADD8E6",
    "light coral": "#F08080",
    "light steel blue": "#B0C4DE",
    "light sky blue": "#87CEFA",
    "light sea green": "#20B2AA",
    "light salmon": "#FFA07A",
    "light slate gray": "#778899",
    "light goldenrod yellow": "#FAFAD2",
    "light orchid": "#E6A8D7",
    "light turquoise": "#AFEEEE",
    "light green yellow": "#ADFF2F",
    "light blue violet": "#8A2BE2",
    "light purple": "#D8BFD8",
    "alice blue": "#F0F8FF",
    "antique white": "#FAEBD7",
    "aqua": "#00FFFF",
    "aquamarine": "#7FFFD4",
    "azure": "#F0FFFF",
    "beige": "#F5F5DC",
    "bisque": "#FFE4C4",
    "blanched almond": "#FFEBCD",
    "blue violet": "#8A2BE2",
    "brown": "#A52A2A",
    "burlywood": "#DEB887",
    "cadet blue": "#5F9EA0",
    "chartreuse": "#7FFF00",
    "chocolate": "#D2691E",
    "coral": "#FF7F50",
    "cornflower blue": "#6495ED",
    "cornsilk": "#FFF8DC",
    "crimson": "#DC143C",
    "dark cyan": "#008B8B",
    "dark goldenrod": "#B8860B",
    "dark gray": "#A9A9A9",
    "dark green": "#006400",
    "dark khaki": "#BDB76B",
    "dark magenta": "#8B008B",
    "dark olive green": "#556B2F",
    "dark orange": "#FF8C00",
    "dark orchid": "#9932CC",
    "dark red": "#8B0000",
    "dark salmon": "#E9967A",
    "dark sea green": "#8FBC8F",
    "dark slate blue": "#483D8B",
    "dark slate gray": "#2F4F4F",
    "dark turquoise": "#00CED1",
    "dark violet": "#9400D3",
    "deep pink": "#FF1493",
    "deep sky blue": "#00BFFF",
    "dim gray": "#696969",
    "dodger blue": "#1E90FF",
    "firebrick": "#B22222",
    "floral white": "#FFFAF0",
    "forest green": "#228B22",
    "gainsboro": "#DCDCDC",
    "ghost white": "#F8F8FF",
    "gold": "#FFD700",
    "goldenrod": "#DAA520",
    "green yellow": "#ADFF2F",
    "honeydew": "#F0FFF0",
    "hot pink": "#FF69B4",
    "indian red": "#CD5C5C",
    "indigo": "#4B0082",
    "ivory": "#FFFFF0",
    "khaki": "#F0E68C",
    "lavender": "#E6E6FA",
    "lavender blush": "#FFF0F5",
    "lawn green": "#7CFC00",
    "lemon chiffon": "#FFFACD",
    "light blue": "#ADD8E6",
    "light coral": "#F08080",
    "light cyan": "#E0FFFF",
    "light goldenrod yellow": "#FAFAD2",
    "light gray": "#D3D3D3",
    "light green": "#90EE90",
    "light pink": "#FFB6C1",
    "light salmon": "#FFA07A",
    "light sea green": "#20B2AA",
    "light sky blue": "#87CEFA",
    "light slate gray": "#778899",
    "light steel blue": "#B0C4DE",
    "light yellow": "#FFFFE0",
    "lime green": "#32CD32",
    "linen": "#FAF0E6",
    "magenta": "#FF00FF",
    "medium aquamarine": "#66CDAA",
    "medium blue": "#0000CD",
    "medium orchid": "#BA55D3",
    "medium purple": "#9370DB",
    "medium sea green": "#3CB371",
    "medium slate blue": "#7B68EE",
    "medium spring green": "#00FA9A",
    "medium turquoise": "#48D1CC",
    "medium violet red": "#C71585",
    "midnight blue": "#191970",
    "mint cream": "#F5FFFA",
    "misty rose": "#FFE4E1",
    "moccasin": "#FFE4B5",
    "navajo white": "#FFDEAD",
    "old lace": "#FDF5E6",
    "olive drab": "#6B8E23",
    "orange": "#FFA500",
    "orange red": "#FF4500",
    "orchid": "#DA70D6",
    "pale goldenrod": "#EEE8AA",
    "pale green": "#98FB98",
    "pale turquoise": "#AFEEEE",
    "pale violet red": "#DB7093",
    "papaya whip": "#FFEFD5",
    "peach puff": "#FFDAB9",
    "peru": "#CD853F",
    "pink": "#FFC0CB",
    "plum": "#DDA0DD",
    "powder blue": "#B0E0E6",
    "rosy brown": "#BC8F8F",
    "royal blue": "#4169E1",
    "saddle brown": "#8B4513",
    "salmon": "#FA8072",
    "sandy brown": "#F4A460",
    "sea green": "#2E8B57",
    "seashell": "#FFF5EE",
    "sienna": "#A0522D",
    "sky blue": "#87CEEB",
    "slate blue": "#6A5ACD",
    "slate gray": "#708090",
    "snow": "#FFFAFA",
    "spring green": "#00FF7F",
    "steel blue": "#4682B4",
    "tan": "#D2B48C",
    "thistle": "#D8BFD8",
    "tomato": "#FF6347",
    "turquoise": "#40E0D0",
    "violet": "#EE82EE",
    "wheat": "#F5DEB3",
    "white smoke": "#F5F5F5",
    "yellow green": "#9ACD32"
    }
    return colors

def get_color_hex(color_name, ask_for_suggestion: bool = False):
    """
    Retrieve the hexadecimal color code corresponding to a given color name.
    
    Args:
        - color_name (str): The name of the color.
        - ask_for_suggestion (bool, optional): Whether to ask for a suggestion if the exact color name is not found. 
            Defaults to False.

    Returns:
        - tuple: A tuple containing the hexadecimal color code and a suggestion if available.
        
    Example:
        >>> color_hex, suggestion = get_color_hex('blue')
        >>> print(color_hex)
        '#0000FF'
        >>> print(suggestion)
        None
        
        >>> color_hex, suggestion = get_color_hex('purole', ask_for_suggestion=True)
        No colors under 'purole' found. Did you mean 'purple'? (yes/no): yes
        >>> print(color_hex)
        '#800080'
        >>> print(suggestion)
        'purple'
    """
    colors = get_all_colors()
    color_name_lower = color_name.lower()
    color = colors.get(color_name_lower)
    if color:
        return color, None
    else:
        similar_colors = get_close_matches(color_name_lower, colors.keys())
        if similar_colors:
            suggestion = similar_colors[0]
            if ask_for_suggestion:
                response = input(f"No colors under '{color_name}' found. Did you mean '{suggestion}'? (yes/no): ")
                if "y" in response.lower():
                    return (f"No colors under '{color_name}' found. Did you mean '{suggestion}'?", suggestion)
                else:
                    return (f"No colors under '{color_name}' found.", suggestion)
            else:
                return (f"No colors under '{color_name}' found. Did you mean '{suggestion}'?", suggestion)
    return (f"No colors under '{color_name}' found.", "No color suggestion found")


def verify_hex_color(color_code):
    """
    Verify if the input string represents a hexadecimal color code.

    Args:
        - color_code (str): The input string to verify.

    Returns:
        - bool: True if the input is a valid hexadecimal color code, False otherwise.

    Example:
        >>> verify_hex_color('#FF0000')
        True
        >>> verify_hex_color('FF0000')
        True
        >>> verify_hex_color('#GG0000')
        False
    """
    # Regular expression pattern to match hexadecimal color codes
    hex_pattern = r'^#?([A-Fa-f0-9]{6}|[A-Fa-f0-9]{3})$'
    
    # Check if the input matches the pattern
    return bool(re.match(hex_pattern, color_code))

def hex_to_int(hex_color):
    """
    Convert a hexadecimal color code to an integer representation.

    Args:
        hex_color (str): The hexadecimal color code.

    Returns:
        int: The integer representation of the hexadecimal color code.
        
    Example:
        >>> hex_to_int('ff0000')
        16711680
        >>> hex_to_int('#00ff00')
        65280
    """
    # Remove '#' if present and convert to integer
    return int(hex_color.lstrip('#'), 16)